@@ -5,12 +5,12 @@ var k=!1;try{h.hasOwnProperty("responseType")&&(h.responseType="arraybuffer",k=!
 h.responseText:null}catch(k){}try{g.binary=h.response}catch(l){}try{f=h.statusText}catch(t){f=""}!b&&a.isLocal&&!a.crossDomain?b=g.text?200:404:1223===b&&(b=204);m(b,f,g,c)}}catch(s){alert(s),m(-1,s)}};a.async?4===h.readyState?setTimeout(d):h.onreadystatechange=d:d()},abort:function(){}}}))})(jQuery);
 (function(a,h,e,d){function g(e,g){function k(b){a(l).each(function(){self.Jmol&&(0<=g.indexOf("mouseup")||0<=g.indexOf("touchend"))&&Jmol._setMouseOwner(null);var c=a(this);this!==b.target&&!c.has(b.target).length&&c.triggerHandler(g,[b.target,b])})}g=g||e+d;var l=a(),b=e+"."+g+"-special-event";a.event.special[g]={setup:function(){l=l.add(this);1===l.length&&a(h).bind(b,k)},teardown:function(){self.Jmol&&Jmol._setMouseOwner(null);l=l.not(this);0===l.length&&a(h).unbind(b)},add:function(b){var a=
 b.handler;b.handler=function(b,f){b.target=f;a.apply(this,arguments)}}}}a.map(e.split(" "),function(a){g(a)});g("focusin","focus"+d);g("focusout","blur"+d)})(jQuery,document,"click mousemove mouseup touchmove touchend","outjsmol");"undefined"==typeof jQuery&&alert("Note -- JSmoljQuery is required for JSmol, but it's not defined.");self.Jmol||(Jmol={});
-Jmol._version||(Jmol=function(a){var h=function(a){return{rear:a++,header:a++,main:a++,image:a++,front:a++,fileOpener:a++,coverImage:a++,dialog:a++,menu:a+9E4,console:a+91E3,consoleImage:a+91001,monitorZIndex:a+99999}},h={_version:"$Date: 2016-10-21 06:39:01 -0500 (Fri, 21 Oct 2016) $",_alertNoBinary:!0,_allowedJmolSize:[25,2048,300],_appletCssClass:"",_appletCssText:"",_fileCache:null,_jarFile:null,_j2sPath:null,_use:null,_j2sLoadMonitorOpacity:90,_applets:{},_asynchronous:!0,_ajaxQueue:[],_persistentMenu:!1,
-_getZOrders:h,_z:h(Jmol.z||9E3),_debugCode:!0,db:{_databasePrefixes:"$=:",_fileLoadScript:";if (_loadScript = '' && defaultLoadScript == '' && _filetype == 'Pdb') { select protein or nucleic;cartoons Only;color structure; select * };",_nciLoadScript:";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",_pubChemLoadScript:"",_DirectDatabaseCalls:{"cactus.nci.nih.gov":null,".x3dna.org":null,"rruff.geo.arizona.edu":null,".rcsb.org":null,"ftp.wwpdb.org":null,
-"pdbe.org":null,"materialsproject.org":null,".ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"www.nmrdb.org/tools/jmol/predict.php":null,$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"https://files.rcsb.org/download/%FILE.pdb","*":"https://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"https://files.rcsb.org/ligands/download/%FILE.cif",":":"https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"},
+Jmol._version||(Jmol=function(a){var h=function(a){return{rear:a++,header:a++,main:a++,image:a++,front:a++,fileOpener:a++,coverImage:a++,dialog:a++,menu:a+9E4,console:a+91E3,consoleImage:a+91001,monitorZIndex:a+99999}},h={_version:"$Date: 2017-01-20 17:45:38 -0600 (Fri, 20 Jan 2017) $",_alertNoBinary:!0,_allowedJmolSize:[25,2048,300],_appletCssClass:"",_appletCssText:"",_fileCache:null,_jarFile:null,_j2sPath:null,_use:null,_j2sLoadMonitorOpacity:90,_applets:{},_asynchronous:!0,_ajaxQueue:[],_persistentMenu:!1,
+_getZOrders:h,_z:h(Jmol.z||9E3),_debugCode:!0,_debugCore:!1,db:{_databasePrefixes:"$=:",_fileLoadScript:";if (_loadScript = '' && defaultLoadScript == '' && _filetype == 'Pdb') { select protein or nucleic;cartoons Only;color structure; select * };",_nciLoadScript:";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",_pubChemLoadScript:"",_DirectDatabaseCalls:{"cactus.nci.nih.gov":null,".x3dna.org":null,"rruff.geo.arizona.edu":null,".rcsb.org":null,
+"ftp.wwpdb.org":null,"pdbe.org":null,"materialsproject.org":null,".ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"www.nmrdb.org/tools/jmol/predict.php":null,$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"https://files.rcsb.org/download/%FILE.pdb","*":"https://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"https://files.rcsb.org/ligands/download/%FILE.cif",":":"https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"},
 _restQueryUrl:"http://www.rcsb.org/pdb/rest/search",_restQueryXml:"<orgPdbQuery><queryType>org.pdb.query.simple.AdvancedKeywordQuery</queryType><description>Text Search</description><keywords>QUERY</keywords></orgPdbQuery>",_restReportUrl:"http://www.pdb.org/pdb/rest/customReport?pdbids=IDLIST&customReportColumns=structureId,structureTitle"},_debugAlert:!1,_document:a,_isXHTML:!1,_lastAppletID:null,_mousePageX:null,_mouseOwner:null,_serverUrl:"https://your.server.here/jsmol.php",_syncId:(""+Math.random()).substring(3),
-_touching:!1,_XhtmlElement:null,_XhtmlAppendChild:!1};a=a.location.href.toLowerCase();h._httpProto=0==a.indexOf("https")?"https://":"http://";h._isFile=0==a.indexOf("file:");h._isFile&&$.ajaxSetup({mimeType:"text/plain"});h._ajaxTestSite=h._httpProto+"google.com";a=h._isFile||0==a.indexOf("http://localhost")||0==a.indexOf("http://127.");h._tracker=!a&&"https://chemapps.stolaf.edu/jmol/JmolTracker.php?id=UA-45940799-1";h._isChrome=0<=navigator.userAgent.toLowerCase().indexOf("chrome");h._isSafari=
-!h._isChrome&&0<=navigator.userAgent.toLowerCase().indexOf("safari");h._isMsie=void 0!==window.ActiveXObject;h._isEdge=0<=navigator.userAgent.indexOf("Edge/");h._useDataURI=!h._isSafari&&!h._isMsie&&!h._isEdge;window.requestAnimationFrame||(window.requestAnimationFrame=window.setTimeout);for(var e in Jmol)h[e]=Jmol[e];return h}(document,Jmol));
+_touching:!1,_XhtmlElement:null,_XhtmlAppendChild:!1};a=a.location.href.toLowerCase();h._debugCore=0<=a.indexOf("j2sdebugcore");h._httpProto=0==a.indexOf("https")?"https://":"http://";h._isFile=0==a.indexOf("file:");h._isFile&&$.ajaxSetup({mimeType:"text/plain"});h._ajaxTestSite=h._httpProto+"google.com";a=h._isFile||0==a.indexOf("http://localhost")||0==a.indexOf("http://127.");h._tracker=!a&&"https://chemapps.stolaf.edu/jmol/JmolTracker.php?id=UA-45940799-1";h._isChrome=0<=navigator.userAgent.toLowerCase().indexOf("chrome");
+h._isSafari=!h._isChrome&&0<=navigator.userAgent.toLowerCase().indexOf("safari");h._isMsie=void 0!==window.ActiveXObject;h._isEdge=0<=navigator.userAgent.indexOf("Edge/");h._useDataURI=!h._isSafari&&!h._isMsie&&!h._isEdge;window.requestAnimationFrame||(window.requestAnimationFrame=window.setTimeout);for(var e in Jmol)h[e]=Jmol[e];return h}(document,Jmol));
 (function(a,h){a.__$=h;h(document).ready(function(){a._document=null});a.$=function(b,a){null==b&&alert(a+arguments.callee.caller.toString());return h(a?"#"+b._id+"_"+a:b)};a._$=function(b){return"string"==typeof b?h("#"+b):b};a.$ajax=function(b){a._ajaxCall=b.url;b.cache="NO"!=b.cache;b.url=a._fixProtocol(b.url);return h.ajax(b)};a._fixProtocol=function(b){0<=b.indexOf("get3d=True")&&(b=b.replace(/get3d\=True/,"get3d=true"));return 0==b.indexOf("http://www.rcsb.org/pdb/files/")&&0>b.indexOf("/ligand/")?
 "http://files.rcsb.org/view/"+b.substring(30).replace(/\.gz/,""):0==b.indexOf("http://")&&("https://"==a._httpProto||0<b.indexOf(".gov/")||0==b.indexOf("http://www.materialsproject"))?"https"+b.substring(4):b};a._getNCIInfo=function(b,f){return a._getFileData("https://cactus.nci.nih.gov/chemical/structure/"+b+"/"+("name"==f?"names":f))};a.$appEvent=function(b,f,c,e){b=a.$(b,f);b.off(c)&&e&&b.on(c,e)};a.$resize=function(b){return h(window).resize(b)};a.$after=function(b,a){return h(b).after(a)};a.$append=
 function(b,a){return h(b).append(a)};a.$bind=function(b,a,c){return c?h(b).bind(a,c):h(b).unbind(a)};a.$closest=function(b,a){return h(b).closest(a)};a.$get=function(b,a){return h(b).get(a)};a.$documentOff=function(b,a){return h(document).off(b,"#"+a)};a.$documentOn=function(b,a,c){return h(document).on(b,"#"+a,c)};a.$getAncestorDiv=function(b,a){return h("div."+a+":has(#"+b+")")[0]};a.$supportsIECrossDomainScripting=function(){return h.support.iecors};a.$attr=function(b,f,c){return a._$(b).attr(f,
@@ -38,12 +38,12 @@ a._isBinaryUrl=function(b){for(var f=a._binaryTypes.length;0<=--f;)if(0<=b.index
 "https://"==a._httpProto&&0==b.indexOf("http://"),j=a._isDirectCall(b);!j&&0<=b.indexOf("?ALLOWSORIGIN?")&&(j=!0,b=b.replace(/\?ALLOWSORIGIN\?/,""));var k=!h&&a.$supportsIECrossDomainScripting(),l=null;if(m||d||!h&&!j||!f&&k)l=a._getRawDataFromServer("_",b,f,f,d,!0);else{b=b.replace(/file:\/\/\/\//,"file://");var n={dataType:e?"binary":"text",async:!!f};g?(n.type="POST",n.url=b.split("?POST?")[0],n.data=b.split("?POST?")[1]):(n.type="GET",n.url=b);f&&(n.success=function(){f(a._xhrReturn(n.xhr))},
 n.error=function(){f(n.xhr.statusText)});n.xhr=a.$ajax(n);f||(l=a._xhrReturn(n.xhr))}if(!c)return l;null==l&&(l="",e=!1);e&&(e=a._canSyncBinary(!0));return e?a._strToBytes(l):JU.SB.newS(l)};a._xhrReturn=function(b){return!b.responseText||self.Clazz&&Clazz.instanceOf(b.response,self.ArrayBuffer)?b.response||b.statusText:b.responseText};a._isDirectCall=function(b){if(0<=b.indexOf("?ALLOWSORIGIN?"))return!0;for(var f in a.db._DirectDatabaseCalls)if(0<=f.indexOf(".")&&0<=b.indexOf(f))return!0;return!1};
 a._cleanFileData=function(b){return 0<=b.indexOf("\r")&&0<=b.indexOf("\n")?b.replace(/\r\n/g,"\n"):0<=b.indexOf("\r")?b.replace(/\r/g,"\n"):b};a._getFileType=function(b){var a=b.substring(0,1);if("$"==a||":"==a)return"MOL";if("="==a)return"="==b.substring(1,2)?"LCIF":"PDB";b=b.split(".").pop().toUpperCase();return b.substring(0,Math.min(b.length,3))};a._getZ=function(b,f){return b&&b._z&&b._z[f]||a._z[f]};a._incrZ=function(b,f){return b&&b._z&&++b._z[f]||++a._z[f]};a._hideLocalFileReader=function(b){b._localReader&&
-a.$setVisible(b._localReader,!1);b._readingLocal=!1;a._setCursor(b,0)};a.loadFileFromDialog=function(b){a._loadFileAsynchronously(null,b,null,null)};a._loadFileAsynchronously=function(b,f,c,e){if(c&&0!=c.indexOf("?")){var d=c;c=a._checkFileName(f,c);var g=function(g){a._setData(b,c,d,g,e,f)},g=a._checkCache(f,c,g);0<=c.indexOf("|")&&(c=c.split("|")[0]);return null==g?null:a._getFileData(c,g)}if(!a.featureDetection.hasFileReader)return b?b.setData(msg,null,null,e,f):alert(msg);f._localReader||(g='<div id="ID" style="z-index:'+
-a._getZ(f,"fileOpener")+';position:absolute;background:#E0E0E0;left:10px;top:10px"><div style="margin:5px 5px 5px 5px;"><button id="ID_loadurl">URL</button><input type="file" id="ID_files" /><button id="ID_loadfile">load</button><button id="ID_cancel">cancel</button></div><div>',a.$after("#"+f._id+"_appletdiv",g.replace(/ID/g,f._id+"_localReader")),f._localReader=a.$(f,"localReader"));a.$appEvent(f,"localReader_loadurl","click");a.$appEvent(f,"localReader_loadurl","click",function(){var b=prompt("Enter a URL");
-b&&(a._hideLocalFileReader(f,0),a._setData(null,b,b,null,e,f))});a.$appEvent(f,"localReader_loadfile","click");a.$appEvent(f,"localReader_loadfile","click",function(){var c=a.$(f,"localReader_files")[0].files[0],d=new FileReader;d.onloadend=function(d){d.target.readyState==FileReader.DONE&&(a._hideLocalFileReader(f,0),a._setData(b,c.name,c.name,d.target.result,e,f))};try{d.readAsArrayBuffer(c)}catch(g){alert("You must select a file first.")}});a.$appEvent(f,"localReader_cancel","click");a.$appEvent(f,
-"localReader_cancel","click",function(){a._hideLocalFileReader(f);b&&b.setData("#CANCELED#",null,null,e,f)});a.$setVisible(f._localReader,!0);f._readingLocal=!0};a._setData=function(b,f,c,e,d,g){e&&(e=a._strToBytes(e));null!=e&&(null==b||0<=f.indexOf(".jdx"))&&a.Cache.put("cache://"+f,e);null==b?g._applet.openFileAsyncSpecial(null==e?f:"cache://"+f,1):b.setData(f,c,e,d)};a._doAjax=function(b,f,c){b=b.toString();if(null!=c)return a._saveFile(b,c);f&&(b+="?POST?"+f);return a._getFileData(b,null,!0)};
-a._saveFile=function(b,f,c,e){if(a._localFileSaveFunction&&a._localFileSaveFunction(b,f))return"OK";b=b.substring(b.lastIndexOf("/")+1);c||(c=0<=b.indexOf(".pdf")?"application/pdf":0<=b.indexOf(".png")?"image/png":0<=b.indexOf(".gif")?"image/gif":0<=b.indexOf(".jpg")?"image/jpg":"");f=(JU?JU:J.util).Base64.getBase64("string"==typeof f?f.getBytes("UTF-8"):f).toString();e||(e="base64");var d=a._serverUrl;d&&0<=d.indexOf("your.server")&&(d="");a._useDataURI||!d?(e=document.createElement("a"),e.href=
-"data:"+c+";base64,"+f,e.type=c||"text/plain;charset=utf-8",e.download=b,e.target="_blank",h("body").append(e),e.click(),e.remove()):(a._formdiv||(a.$after("body",'<div id="__jsmolformdiv__" style="display:none">\t\t\t\t\t\t<form id="__jsmolform__" method="post" target="_blank" action="">\t\t\t\t\t\t<input name="call" value="saveFile"/>\t\t\t\t\t\t<input id="__jsmolmimetype__" name="mimetype" value=""/>\t\t\t\t\t\t<input id="__jsmolencoding__" name="encoding" value=""/>\t\t\t\t\t\t<input id="__jsmolfilename__" name="filename" value=""/>\t\t\t\t\t\t<textarea id="__jsmoldata__" name="data"></textarea>\t\t\t\t\t\t</form>\t\t\t\t\t\t</div>'),
+a.$setVisible(b._localReader,!1);b._readingLocal=!1;a._setCursor(b,0)};a.loadFileFromDialog=function(b){a._loadFileAsynchronously(null,b,null,null)};a._loadFileAsynchronously=function(b,f,c,e){if(c&&0!=c.indexOf("?")){var d=c;c=a._checkFileName(f,c);var g=function(g){a._setData(b,c,d,g,e,f)},g=a._checkCache(f,c,g);0<=c.indexOf("|")&&(c=c.split("|")[0]);return null==g?null:a._getFileData(c,g)}if(!a.featureDetection.hasFileReader)return b?b.setData("Local file reading is not enabled in your browser",
+null,null,e,f):alert("Local file reading is not enabled in your browser");f._localReader||(g='<div id="ID" style="z-index:'+a._getZ(f,"fileOpener")+';position:absolute;background:#E0E0E0;left:10px;top:10px"><div style="margin:5px 5px 5px 5px;"><button id="ID_loadurl">URL</button><input type="file" id="ID_files" /><button id="ID_loadfile">load</button><button id="ID_cancel">cancel</button></div><div>',a.$after("#"+f._id+"_appletdiv",g.replace(/ID/g,f._id+"_localReader")),f._localReader=a.$(f,"localReader"));
+a.$appEvent(f,"localReader_loadurl","click");a.$appEvent(f,"localReader_loadurl","click",function(){var b=prompt("Enter a URL");b&&(a._hideLocalFileReader(f,0),a._setData(null,b,b,null,e,f))});a.$appEvent(f,"localReader_loadfile","click");a.$appEvent(f,"localReader_loadfile","click",function(){var c=a.$(f,"localReader_files")[0].files[0],d=new FileReader;d.onloadend=function(d){d.target.readyState==FileReader.DONE&&(a._hideLocalFileReader(f,0),a._setData(b,c.name,c.name,d.target.result,e,f))};try{d.readAsArrayBuffer(c)}catch(g){alert("You must select a file first.")}});
+a.$appEvent(f,"localReader_cancel","click");a.$appEvent(f,"localReader_cancel","click",function(){a._hideLocalFileReader(f);b&&b.setData("#CANCELED#",null,null,e,f)});a.$setVisible(f._localReader,!0);f._readingLocal=!0};a._setData=function(b,f,c,e,d,g){e&&(e=a._strToBytes(e));null!=e&&(null==b||0<=f.indexOf(".jdx"))&&a.Cache.put("cache://"+f,e);null==b?g._applet.openFileAsyncSpecial(null==e?f:"cache://"+f,1):b.setData(f,c,e,d)};a._doAjax=function(b,f,c){b=b.toString();if(null!=c)return a._saveFile(b,
+c);f&&(b+="?POST?"+f);return a._getFileData(b,null,!0)};a._saveFile=function(b,f,c,e){if(a._localFileSaveFunction&&a._localFileSaveFunction(b,f))return"OK";b=b.substring(b.lastIndexOf("/")+1);c||(c=0<=b.indexOf(".pdf")?"application/pdf":0<=b.indexOf(".png")?"image/png":0<=b.indexOf(".gif")?"image/gif":0<=b.indexOf(".jpg")?"image/jpg":"");f=(JU?JU:J.util).Base64.getBase64("string"==typeof f?f.getBytes("UTF-8"):f).toString();e||(e="base64");var d=a._serverUrl;d&&0<=d.indexOf("your.server")&&(d="");
+a._useDataURI||!d?(e=document.createElement("a"),e.href="data:"+c+";base64,"+f,e.type=c||"text/plain;charset=utf-8",e.download=b,e.target="_blank",h("body").append(e),e.click(),e.remove()):(a._formdiv||(a.$after("body",'<div id="__jsmolformdiv__" style="display:none">\t\t\t\t\t\t<form id="__jsmolform__" method="post" target="_blank" action="">\t\t\t\t\t\t<input name="call" value="saveFile"/>\t\t\t\t\t\t<input id="__jsmolmimetype__" name="mimetype" value=""/>\t\t\t\t\t\t<input id="__jsmolencoding__" name="encoding" value=""/>\t\t\t\t\t\t<input id="__jsmolfilename__" name="filename" value=""/>\t\t\t\t\t\t<textarea id="__jsmoldata__" name="data"></textarea>\t\t\t\t\t\t</form>\t\t\t\t\t\t</div>'),
 a._formdiv="__jsmolform__"),a.$attr(a._formdiv,"action",d+"?"+(new Date).getMilliseconds()),a.$val("__jsmoldata__",f),a.$val("__jsmolfilename__",b),a.$val("__jsmolmimetype__",c),a.$val("__jsmolencoding__",e),a.$submit("__jsmolform__"),a.$val("__jsmoldata__",""),a.$val("__jsmolfilename__",""));return"OK"};a._strToBytes=function(b){if(Clazz.instanceOf(b,self.ArrayBuffer))return Clazz.newByteArray(-1,b);for(var a=Clazz.newByteArray(b.length,0),c=b.length;0<=--c;)a[c]=b.charCodeAt(c)&255;return a};a._setConsoleDiv=
 function(b){self.Clazz&&Clazz.setConsoleDiv(b)};a._registerApplet=function(b,f){return window[b]=a._applets[b]=a._applets[b+"__"+a._syncId+"__"]=f};a._readyCallback=function(b,f,c,e,d){b=b.split("_object")[0];var g=a._applets[b];if(c=c.booleanValue?c.booleanValue():c)g._appletPanel=d||e,g._applet=e;a._track(g)._readyCallback(b,f,c)};a._getWrapper=function(b,f){var c;if(f){var e="";if(b._coverImage)var e=' onclick="Jmol.coverApplet(ID, false)" title="'+b._coverTitle+'"',d='<image id="ID_coverclickgo" src="'+
 b._makeLiveImage+'" style="width:25px;height:25px;position:absolute;bottom:10px;left:10px;z-index:'+a._getZ(b,"coverImage")+';opacity:0.5;"'+e+" />",e='<div id="ID_coverdiv" style="background-color:red;z-index:'+a._getZ(b,"coverImage")+';width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px"><image id="ID_coverimage" src="'+b._coverImage+'" style="width:100%;height:100%"'+e+"/>"+d+"</div>";d=b._isJava?"":'<image id="ID_waitimage" src="'+b._j2sPath+'/img/cursor_wait.gif" style="display:none;position:absolute;bottom:10px;left:10px;z-index:'+
@@ -72,8 +72,8 @@ a._mousePageY;this.container.css({top:a._mousePageY+"px",left:a._mousePageX+"px"
 this.container.unbind("touchendoutjsmol");a._setMouseOwner(null);if(b){var c=this;this.container.bind("mousemoveoutjsmol touchmoveoutjsmol",function(b,a,e){c.mouseMove(e)});this.container.bind("mouseupoutjsmol touchendoutjsmol",function(b,a,e){c.mouseUp(e)})}})};k.JSDialog=function(){};k.setDraggable(k.JSDialog);k.getScreenDimensions=function(b){b.width=h(window).width();b.height=h(window).height()};k.dispose=function(b){a.$remove(b.id+"_mover");delete k.htDialogs[b.id];b.container.obj.dragBind(!1)};
 k.register=function(b,a){b.id=a+ ++k.count;k.htDialogs[b.id]=b};k.setDialog=function(b){a._setMouseOwner(null);a.$remove(b.id);var e=b.id+"_mover",c=a._$(e),d;c[0]?(c.html(b.html),d=c[0].jd):(a.$after("body","<div id='"+e+"' style='position:absolute;left:0px;top:0px;'>"+b.html+"</div>"),d=new k.JSDialog,c=a._$(e),b.container=c,d.applet=b.manager.vwr.html5Applet,d.setContainer(c),d.dialog=b,d.setPosition(),d.dragBind(!0),c[0].jd=d);a.$bind("#"+b.id+" .JButton","mousedown touchstart",function(){d.ignoreMouse=
 !0});a.$bind("#"+b.id+" .JComboBox","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JCheckBox","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JTextField","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JTable","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JScrollPane","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JEditorPane","mousedown touchstart",function(){d.ignoreMouse=
-!0})};k.setSelected=function(b){a.$prop(b.id,"checked",!!b.selected)};k.setSelectedIndex=function(b){a.$prop(b.id,"selectedIndex",b.selectedIndex)};k.setText=function(b){a.$prop(b.id,"value",b.text)};k.setVisible=function(b){a.$setVisible(b.id,b.visible)};k.setEnabled=function(b){a.$setEnabled(b.id,b.enabled)};k.click=function(b,e){var c=k.htDialogs[b.id];if(c){var d=c.toString();if(0<=d.indexOf("JCheck"))c.selected=b.checked;else if(0<=d.indexOf("JCombo"))c.selectedIndex=b.selectedIndex;else if(null!=
-c.text&&(c.text=b.value,e&&13!=(e.charCode||e.keyCode)))return}d=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];d.manager.actionPerformed(c?c.name:d.registryKey+"/"+b.id)};k.setFront=function(b){var e=b.manager.vwr.html5Applet;b.zIndex!=a._getZ(e,"dialog")&&(b.zIndex=a._incrZ(e,"dialog"));b.container&&((b.container[0]||b.container).style.zIndex=b.zIndex)};k.hideMenus=function(b){if(b=b._menus)for(var a in b)b[a].visible&&k.hideMenu(b[a])};k.windowClosing=function(b){b=k.htDialogs[a.$getAncestorDiv(b.id,
+!0})};k.setSelected=function(b){a.$prop(b.id,"checked",!!b.selected)};k.setSelectedIndex=function(b){a.$prop(b.id,"selectedIndex",b.selectedIndex)};k.setText=function(b){a.$prop(b.id,"value",b.text)};k.setVisible=function(b){a.$setVisible(b.id,b._visible)};k.setEnabled=function(b){a.$setEnabled(b.id,b.enabled)};k.click=function(b,e){var c=k.htDialogs[b.id];if(c){var d=c.toString();if(0<=d.indexOf("JCheck"))c.selected=b.checked;else if(0<=d.indexOf("JCombo"))c.selectedIndex=b.selectedIndex;else if(null!=
+c.text&&(c.text=b.value,e&&13!=(e.charCode||e.keyCode)))return}d=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];d.manager.actionPerformed(c?c.name:d.registryKey+"/"+b.id)};k.setFront=function(b){var e=b.manager.vwr.html5Applet;b.zIndex!=a._getZ(e,"dialog")&&(b.zIndex=a._incrZ(e,"dialog"));b.container&&((b.container[0]||b.container).style.zIndex=b.zIndex)};k.hideMenus=function(b){if(b=b._menus)for(var a in b)b[a]._visible&&k.hideMenu(b[a])};k.windowClosing=function(b){b=k.htDialogs[a.$getAncestorDiv(b.id,
 "JDialog").id];b.registryKey?b.manager.processWindowClosing(b.registryKey):b.dispose()};a._track=function(b){if(a._tracker){try{var e='<iframe style="display:none" width="0" height="0" frameborder="0" tabindex="-1" src="'+(a._tracker+"&applet="+b._jmolType+"&version="+a._version+"&appver="+a.___JmolVersion+"&url="+encodeURIComponent(document.location.href))+'"></iframe>';a.$after("body",e)}catch(c){}delete a._tracker}return b};var l;a.getProfile=function(b){if(self.Clazz&&self.JSON)return l||Clazz._startProfiling(l=
 0==arguments.length||b),Clazz.getProfile()};a._getInChIKey=function(b,a){0<=a.indexOf("MOL=")&&a.split("MOL=")[1].split('"')};a._getAttr=function(b,a){var e=b.indexOf(a+"=");return 0<=e&&0<=(e=b.indexOf('"',e))?b.substring(e+1,b.indexOf('"',e+1)):null};a.User={viewUpdatedCallback:null};a.View={count:0,applets:{},sets:{}};(function(b){b.resetView=function(b,e){debugger;if(e){if(e._viewSet){var d=a.View.applets[e._viewSet];for(b in d)b!=e&&a.View.resetView(b)}}else b&&(b._reset(),a.View.updateView(b))};
 b.updateView=function(e,c){if(null!=e._viewSet){c||(c={});c.chemID||(e._searchQuery=null);c.data||(c.data="N/A");c.type=e._viewType;if(null==(e._currentView=b.__findView(e._viewSet,c)))e._currentView=b.__createViewSet(e._viewSet,c.chemID,c.viewID||c.chemID);e._currentView[c.type].data=c.data;e._currentView[c.type].smiles=e._getSmiles();a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(e,"updateView");b.__setView(e._currentView,e,!1)}};b.updateFromSync=function(e,c){e._updateMsg=c;var d=a._getAttr(c,
