@@ -210,6 +210,10 @@ return 514;
 case 8:
 case 9:
 return 33;
+case 15:
+return 5;
+case 16:
+return 6;
 }
 return order;
 }, "~N,~N");
