@@ -635,15 +635,16 @@ var isNegOffset = false;
 var nboType = null;
 var bsModels = this.vwr.getVisibleFramesBitSet ();
 var propertyList =  new JU.Lst ();
+var isBeta = false;
 var i0 = 1;
-if (this.tokAt (0) == 1073877011 && this.e.slen == 1) {
+if (this.tokAt (0) == 1073877011) {
+var isViewOnly = this.e.optParameterAsString (1).equals ("view");
+if (this.e.slen == 1 || isViewOnly || this.e.optParameterAsString (1).equals ("options")) {
 if (!this.chk) {
-var htParams =  new java.util.Hashtable ();
-htParams.put ("service", "nbo");
-htParams.put ("action", "showPanel");
-this.vwr.sm.processService (htParams);
+var options = (isViewOnly ? "VIEW" : this.e.optParameterAsString (2));
+this.vwr.startNBO (options);
 }return;
-}if (this.tokAt (1) == 1094717454 || this.tokAt (1) == 4115) {
+}}if (this.tokAt (1) == 1094717454 || this.tokAt (1) == 4115) {
 i0 = eval.modelNumberParameter (2);
 if (i0 < 0) this.invArg ();
 bsModels.clearAll ();
@@ -684,7 +685,10 @@ offset = moNumber = 0;
 break;
 case 2:
 moNumber = this.intParameter (i);
-linearCombination = this.moCombo (propertyList);
+if (this.tokAt (i + 1) == 1073741865) {
+isBeta = true;
+i++;
+}linearCombination = this.moCombo (propertyList);
 if (linearCombination == null && moNumber < 0) linearCombination =  Clazz.newFloatArray (-1, [-100, -moNumber]);
 ignoreSquared = true;
 break;
@@ -706,11 +710,13 @@ ignoreSquared = true;
 break;
 case 1073742037:
 moNumber = 1073742037;
+isBeta = false;
 linearCombination = this.moCombo (propertyList);
 ignoreSquared = true;
 break;
 case 1073742108:
 moNumber = 1073742108;
+isBeta = false;
 linearCombination = this.moCombo (propertyList);
 ignoreSquared = true;
 break;
@@ -782,17 +788,20 @@ if (this.chk) return;
 if (nboType != null || haveMO) {
 if (haveMO && this.tokAt (eval.iToken + 1) == 4) title = this.paramAsStr (++eval.iToken);
 eval.setCursorWait (true);
-this.setMoData (propertyList, moNumber, linearCombination, offset, isNegOffset, iModel, title, nboType);
-if (haveMO) this.addShapeProperty (propertyList, "finalize", null);
-}if (!ignoreSquared) {
+this.setMoData (propertyList, moNumber, linearCombination, offset, isNegOffset, iModel, title, nboType, isBeta);
+if (haveMO) {
+this.addShapeProperty (propertyList, "finalize", null);
+}}if (!ignoreSquared) {
 this.setShapeProperty (iShape, "squareLinear", linearSquared);
 this.setShapeProperty (iShape, "squareData", squared);
 }if (propertyList.size () > 0) this.setShapeProperty (iShape, "setProperties", propertyList);
-propertyList.clear ();
+if (haveMO && !eval.tQuiet) {
+this.showString (JS.T.nameOf (this.tokAt (0)) + " " + moNumber + " " + (isBeta ? "beta " : "") + this.getShapeProperty (iShape, "message"));
+}propertyList.clear ();
 }
 }, "~B,~N");
 Clazz.defineMethod (c$, "setNBOType", 
- function (moData, type) {
+ function (moData, type, isBeta) {
 var ext = ";AO;  ;PNAO;;NAO; ;PNHO;;NHO; ;PNBO;;NBO; ;PNLMO;NLMO;;MO;  ;NO;".indexOf (";" + type + ";");
 if (ext < 0) this.invArg ();
 ext = Clazz.doubleToInt (ext / 6) + 31;
@@ -816,14 +825,22 @@ mo.put ("dfCoefMaps", dfCoefMaps);
 }
 (J.api.Interface.getInterface ("J.quantum.QS", this.vwr, "script")).setNboLabels (nboLabels, n, orbitals, 0, type);
 data = data.substring (data.lastIndexOf ("--") + 2);
-var len = data.length;
+var nao = n;
+if (data.indexOf ("alpha") >= 0) {
+nao = Clazz.doubleToInt (n / 2);
+data = data.substring (data.indexOf ("alpha") + 10);
+}var len = data.length;
 var next =  Clazz.newIntArray (1, 0);
 for (var i = 0; i < n; i++) {
-var mo = orbitals.get (i);
-var coefs =  Clazz.newFloatArray (n, 0);
+if (i == nao) {
+next[0] += 12;
+}var mo = orbitals.get (i);
+var coefs =  Clazz.newFloatArray (nao, 0);
 mo.put ("coefficients", coefs);
-for (var j = 0; j < n; j++) coefs[j] = JU.PT.parseFloatChecked (data, len, next, false);
-
+for (var j = 0; j < nao; j++) {
+coefs[j] = JU.PT.parseFloatChecked (data, len, next, false);
+if (Float.isNaN (coefs[j])) System.out.println ("oops = IsoExt ");
+}
 }
 if (type.equals ("NBO")) {
 var occupancies =  Clazz.newFloatArray (n, 0);
@@ -843,7 +860,7 @@ this.error (27);
 throw e;
 }
 }
-}, "java.util.Map,~S");
+}, "java.util.Map,~S,~B");
 Clazz.defineMethod (c$, "moCombo", 
  function (propertyList) {
 if (this.tokAt (this.e.iToken + 1) != 1073742156) return null;
@@ -862,7 +879,7 @@ if (tok == 2 && this.intParameter (index) < 0) offset += this.intParameter (inde
 return offset;
 }, "~N");
 Clazz.defineMethod (c$, "setMoData", 
- function (propertyList, moNumber, lc, offset, isNegOffset, modelIndex, title, nboType) {
+ function (propertyList, moNumber, lc, offset, isNegOffset, modelIndex, title, nboType, isBeta) {
 var eval = this.e;
 if (modelIndex < 0) {
 modelIndex = this.vwr.am.cmi;
@@ -871,7 +888,7 @@ if (modelIndex < 0) eval.errorStr (30, "MO isosurfaces");
 if (moData == null) this.error (27);
 this.vwr.checkMenuUpdate ();
 if (nboType != null) {
-this.setNBOType (moData, nboType);
+this.setNBOType (moData, nboType, isBeta);
 if (lc == null && moNumber == 2147483647) return;
 }var mos = null;
 var mo;
@@ -879,6 +896,7 @@ var nOrb = 0;
 var f = null;
 if (lc == null || lc.length < 2) {
 if (lc != null && lc.length == 1) offset = 0;
+ else if (isBeta && moData.containsKey ("firstBeta")) offset = (moData.get ("firstBeta")).intValue ();
 var lastMoNumber = (moData.containsKey ("lastMoNumber") ? (moData.get ("lastMoNumber")).intValue () : 0);
 var lastMoCount = (moData.containsKey ("lastMoCount") ? (moData.get ("lastMoCount")).intValue () : 1);
 if (moNumber == 1073742108) moNumber = lastMoNumber - 1;
@@ -888,7 +906,8 @@ nOrb = (mos == null ? 0 : mos.size ());
 if (nOrb == 0) this.error (25);
 if (nOrb == 1 && moNumber > 1) this.error (29);
 if (offset != 2147483647) {
-if (moData.containsKey ("HOMO")) {
+if (isBeta) {
+} else if (moData.containsKey ("HOMO")) {
 moNumber = (moData.get ("HOMO")).intValue () + offset;
 } else {
 moNumber = nOrb;
@@ -907,8 +926,8 @@ break;
 }break;
 }
 if (f == null) this.error (28);
-moNumber += offset;
-}if (!this.chk) JU.Logger.info ("MO " + moNumber);
+}moNumber += offset;
+if (!this.chk) JU.Logger.info ("MO " + moNumber);
 }if (moNumber < 1 || moNumber > nOrb) eval.errorStr (26, "" + nOrb);
 }moNumber = Math.abs (moNumber);
 moData.put ("lastMoNumber", Integer.$valueOf (moNumber));
@@ -942,7 +961,7 @@ moData.put ("lastMoCount", Integer.$valueOf (Clazz.doubleToInt (n / 2)));
 if (title != null) this.addShapeProperty (propertyList, "title", title);
 this.addShapeProperty (propertyList, "molecularOrbital", lc != null ? lc : Integer.$valueOf (Math.abs (moNumber)));
 this.addShapeProperty (propertyList, "clear", null);
-}, "JU.Lst,~N,~A,~N,~B,~N,~S,~S");
+}, "JU.Lst,~N,~A,~N,~B,~N,~S,~S,~B");
 Clazz.defineMethod (c$, "isosurface", 
  function (iShape) {
 var eval = this.e;
@@ -962,6 +981,7 @@ var isBicolor = false;
 var isPhased = false;
 var doCalcArea = false;
 var doCalcVolume = false;
+var isBeta = false;
 var isCavity = false;
 var haveRadius = false;
 var toCache = false;
@@ -969,6 +989,7 @@ var isFxy = false;
 var haveSlab = false;
 var haveIntersection = false;
 var isFrontOnly = false;
+var nbotype = null;
 var data = null;
 var cmd = null;
 var thisSetNumber = -2147483648;
@@ -1358,7 +1379,7 @@ sbCommand.append (" ").append (JU.Escape.escapeColor (color));
 isBicolor = true;
 } else if (isSign) {
 this.invPO ();
-}} else if (!isSign && discreteColixes == null) {
+}} else if (!isSign && discreteColixes == null && colorScheme == null) {
 this.invPO ();
 }continue;
 case 134221829:
@@ -1437,7 +1458,11 @@ default:
 this.error (14);
 }
 break;
+case 1073877011:
+nbotype = this.paramAsStr (++i).toUpperCase ();
+sbCommand.append (" nbo ").append (nbotype).append (" ");
 case 1073877010:
+if (nbotype == null) sbCommand.append (" mo ");
 var moNumber = 2147483647;
 var offset = 2147483647;
 var isNegOffset = (this.tokAt (i + 1) == 268435616);
@@ -1448,7 +1473,7 @@ case 0:
 eval.bad ();
 break;
 case 1073741914:
-sbCommand.append ("mo [1] squared ");
+sbCommand.append ("[1] squared ");
 this.addShapeProperty (propertyList, "squareLinear", Boolean.TRUE);
 linearCombination =  Clazz.newFloatArray (-1, [1]);
 offset = moNumber = 0;
@@ -1459,14 +1484,17 @@ case 1073742008:
 offset = this.moOffset (i);
 moNumber = 0;
 i = eval.iToken;
-sbCommand.append (" mo " + (isNegOffset ? "-" : "") + "HOMO ");
+sbCommand.append ((isNegOffset ? "-" : "") + "HOMO ");
 if (offset > 0) sbCommand.append ("+");
 if (offset != 0) sbCommand.appendI (offset);
 break;
 case 2:
 moNumber = this.intParameter (i);
-sbCommand.append (" mo ").appendI (moNumber);
-break;
+sbCommand.appendI (moNumber);
+if (this.tokAt (i + 1) == 1073741865) {
+isBeta = true;
+i++;
+}break;
 default:
 if (eval.isArrayParameter (i)) {
 linearCombination = eval.floatParameterSet (i, 1, 2147483647);
@@ -1484,14 +1512,14 @@ var seed = (this.tokAt (i + 1) == 2 ? this.intParameter (++i) : (-System.current
 this.addShapeProperty (propertyList, "monteCarloCount", Integer.$valueOf (monteCarloCount));
 this.addShapeProperty (propertyList, "randomSeed", Integer.$valueOf (seed));
 sbCommand.append (" points ").appendI (monteCarloCount).appendC (' ').appendI (seed);
-}this.setMoData (propertyList, moNumber, linearCombination, offset, isNegOffset, modelIndex, null, null);
+}this.setMoData (propertyList, moNumber, linearCombination, offset, isNegOffset, modelIndex, null, nbotype, isBeta);
 surfaceObjectSeen = true;
 continue;
 case 1073742036:
 propertyName = "nci";
 sbCommand.append (" " + propertyName);
 var tok = this.tokAt (i + 1);
-var isPromolecular = (tok != 1228935687 && tok != 4 && tok != 1073742033);
+var isPromolecular = (tok != 1228935687 && tok != 4 && tok != 1073742032);
 propertyValue = Boolean.$valueOf (isPromolecular);
 if (isPromolecular) surfaceObjectSeen = true;
 break;
@@ -1671,7 +1699,7 @@ i = eval.iToken;
 break;
 case 1073741932:
 sbCommand.append (" ed");
-this.setMoData (propertyList, -1, null, 0, false, modelIndex, null, null);
+this.setMoData (propertyList, -1, null, 0, false, modelIndex, null, null, false);
 surfaceObjectSeen = true;
 continue;
 case 536870916:
@@ -1887,7 +1915,7 @@ sbCommand.append (" full");
 i++;
 }surfaceObjectSeen = true;
 break;
-case 1073742033:
+case 1073742032:
 this.addShapeProperty (propertyList, "fileType", "Mrc");
 sbCommand.append (" mrc");
 continue;
@@ -1896,7 +1924,7 @@ case 1073742062:
 this.addShapeProperty (propertyList, "fileType", "Obj");
 sbCommand.append (" obj");
 continue;
-case 1073742034:
+case 1073742033:
 this.addShapeProperty (propertyList, "fileType", "Msms");
 sbCommand.append (" msms");
 continue;
