@@ -867,8 +867,9 @@ var argLast = (args.length > 0 ? args[args.length - 1] : JS.SV.vF);
 var isON = !isList && (argLast.tok == 1073742335);
 try {
 if (isChemical) {
-var data = (x1.tok == 10 ? this.vwr.getOpenSmiles (x1.value) : JS.SV.sValue (x1));
-data = (data.length == 0 ? "" : this.vwr.getChemicalInfo (data, flags.toLowerCase ())).trim ();
+var bsAtoms = (x1.tok == 10 ? x1.value : null);
+var data = (bsAtoms == null ? JS.SV.sValue (x1) : this.vwr.getOpenSmiles (bsAtoms));
+data = (data.length == 0 ? "" : this.vwr.getChemicalInfo (data, flags.toLowerCase (), bsAtoms)).trim ();
 if (data.startsWith ("InChI")) data = JU.PT.rep (JU.PT.rep (data, "InChI=", ""), "InChIKey=", "");
 return mp.addXStr (data);
 }if (isSmiles || isSMARTS || x1.tok == 10) {
@@ -1729,7 +1730,7 @@ q = JU.Quat.newM (args[0].value);
 p4 = args[0].value;
 } else {
 var s = JS.SV.sValue (args[0]);
-var v = JU.Escape.uP (s.equalsIgnoreCase ("best") ? this.vwr.getOrientationText (1073741863, null) : s);
+var v = JU.Escape.uP (s.equalsIgnoreCase ("best") ? this.vwr.getOrientationText (1073741864, null) : s);
 if (!(Clazz.instanceOf (v, JU.P4))) return false;
 p4 = v;
 }if (tok == 134217731) q = JU.Quat.newVA (JU.P3.new3 (p4.x, p4.y, p4.z), p4.w);
@@ -2190,7 +2191,7 @@ case 136314895:
 case 2097184:
 case 1678381065:
 return mp.addXBs (ms.getAtoms (tok, null));
-case 1073741864:
+case 1073741863:
 return mp.addXBs (ms.getAtoms (tok, ""));
 case 1073742362:
 return mp.addXBs (ms.getAtoms (1086324744, withinStr));
@@ -2204,7 +2205,7 @@ break;
 case 1073741824:
 case 1086326786:
 case 1086326785:
-case 1073741864:
+case 1073741863:
 case 1086324744:
 case 1073741916:
 case 1073742128:
