@@ -241,8 +241,8 @@ function (fpt) {
 return this.unitCell.toSupercell (fpt);
 }, "JU.P3");
 Clazz.defineMethod (c$, "toFractional", 
-function (pt, isAbsolute) {
-if (!this.$isBio) this.unitCell.toFractional (pt, isAbsolute);
+function (pt, ignoreOffset) {
+if (!this.$isBio) this.unitCell.toFractional (pt, ignoreOffset);
 }, "JU.T3,~B");
 Clazz.overrideMethod (c$, "toFractionalM", 
 function (m) {
