@@ -83,8 +83,13 @@ if (Double.isNaN (x1)) {
 this.haveRegions = false;
 this.clear ();
 return null;
+}if (Double.isNaN (x2)) {
+return this.splitIntegral (x1);
 }if (x1 == x2) return null;
-var y1 = this.getYValueAt (x1);
+if (x1 < x2) {
+this.clear (x1, x2);
+return null;
+}var y1 = this.getYValueAt (x1);
 var y2 = this.getYValueAt (x2);
 this.haveRegions = true;
 var $in =  new JSV.common.Integral ().setInt (x1, y1, this.spec, Math.abs (y2 - y1) * 100 * this.normalizationFactor, x2, y2);
@@ -93,6 +98,16 @@ this.addLast ($in);
 java.util.Collections.sort (this, JSV.common.IntegralData.c);
 return $in;
 }, "~N,~N");
+Clazz.defineMethod (c$, "splitIntegral", 
+ function (x) {
+var i = this.find (x);
+if (i < 0) return null;
+var integral = this.removeItemAt (i);
+var x0 = integral.getXVal ();
+var x2 = integral.getXVal2 ();
+this.addIntegralRegion (x0, x);
+return this.addIntegralRegion (x, x2);
+}, "~N");
 Clazz.overrideMethod (c$, "setSpecShift", 
 function (dx) {
 JSV.common.Coordinate.shiftX (this.xyCoords, dx);
@@ -165,9 +180,9 @@ this.percentOffset = Math.max (5, this.percentOffset);
 this.percentRange = Math.max (10, this.percentRange);
 });
 c$.getIntegrationRatiosFromString = Clazz.defineMethod (c$, "getIntegrationRatiosFromString", 
-function (spec, value) {
+function (spec, key_values) {
 var ratios =  new JU.Lst ();
-var allParamTokens =  new java.util.StringTokenizer (value, ",");
+var allParamTokens =  new java.util.StringTokenizer (key_values, ",");
 while (allParamTokens.hasMoreTokens ()) {
 var token = allParamTokens.nextToken ();
 var eachParam =  new java.util.StringTokenizer (token, ":");
@@ -303,7 +318,7 @@ c$.getMode = Clazz.defineMethod (c$, "getMode",
 function (a) {
 for (var mode, $mode = 0, $$mode = JSV.common.IntegralData.IntMode.values (); $mode < $$mode.length && ((mode = $$mode[$mode]) || true); $mode++) if (a.startsWith (mode.name ())) return mode;
 
-return JSV.common.IntegralData.IntMode.ON;
+return JSV.common.IntegralData.IntMode.NA;
 }, "~S");
 Clazz.defineEnumConstant (c$, "OFF", 0, []);
 Clazz.defineEnumConstant (c$, "ON", 1, []);
@@ -313,6 +328,8 @@ Clazz.defineEnumConstant (c$, "LIST", 4, []);
 Clazz.defineEnumConstant (c$, "MARK", 5, []);
 Clazz.defineEnumConstant (c$, "MIN", 6, []);
 Clazz.defineEnumConstant (c$, "UPDATE", 7, []);
+Clazz.defineEnumConstant (c$, "CLEAR", 8, []);
+Clazz.defineEnumConstant (c$, "NA", 9, []);
 c$ = Clazz.p0p ();
 Clazz.defineStatics (c$,
 "DEFAULT_OFFSET", 30,
