@@ -680,6 +680,7 @@ Clazz_defineMethod (c$, "setVisible",
 function (tf) {
 if (tf && this.html == null) this.setDialog ();
 Clazz_superCall (this, javajs.swing.JDialog, "setVisible", [tf]);
+if (tf) this.toFront ();
 }, "~B");
 Clazz_defineMethod (c$, "dispose", 
 function () {
@@ -699,9 +700,9 @@ SwingController.setDialog(this);
 }});
 Clazz_overrideMethod (c$, "toHTML", 
 function () {
-this.renderWidth = this.getSubcomponentWidth ();
+this.renderWidth = Math.max (this.width, this.getSubcomponentWidth ());
 if (this.renderWidth == 0) this.renderWidth = this.defaultWidth;
-this.renderHeight = this.contentPane.getSubcomponentHeight ();
+this.renderHeight = Math.max (this.height, this.contentPane.getSubcomponentHeight ());
 if (this.renderHeight == 0) this.renderHeight = this.defaultHeight;
 var h = this.renderHeight - 25;
 var sb =  new JU.SB ();
@@ -712,6 +713,11 @@ sb.append (this.contentPane.toHTML ());
 sb.append ("\n</div></div>\n");
 return sb.toString ();
 });
+Clazz_defineMethod (c$, "toFront", 
+function () {
+{
+SwingController.setFront(this);
+}});
 Clazz_defineStatics (c$,
 "headerHeight", 25);
 });
